@@ -1,7 +1,9 @@
 """
-   File Name：     __init__
+   File Name：     __init__.py
    Description :
    Author :       abhay
    date：          2022/10/24
    University: Chengdu University of Technology.
 """
+import pygeotimes
+from geotext import GeoText
\ No newline at end of file
